contacts.Partners (Partners) — amici1

# `contacts.Partners` (Partners)

Columns

- `<django.db.models.fields.BigAutoField: id>`

- `<django.db.models.fields.EmailField: email>`

- `<lino.utils.mldbc.fields.LanguageField: language>`

- `<django.db.models.fields.URLField: url>`

- `<django.db.models.fields.CharField: phone>`

- `<django.db.models.fields.CharField: gsm>`

- `<django.db.models.fields.CharField: fax>`

- `<django.db.models.fields.related.ForeignKey: country>`

- `<django.db.models.fields.related.ForeignKey: city>`

- `<django.db.models.fields.CharField: zip_code>`

- `<django.db.models.fields.related.ForeignKey: region>`

- `<django.db.models.fields.CharField: addr1>`

- `<django.db.models.fields.CharField: street_prefix>`

- `<django.db.models.fields.CharField: street>`

- `<django.db.models.fields.CharField: street_no>`

- `<django.db.models.fields.CharField: street_box>`

- `<django.db.models.fields.CharField: addr2>`

- `<django.db.models.fields.CharField: prefix>`

- `<django.db.models.fields.CharField: name>`

- `<django.db.models.fields.TextField: remarks>`

- `<django.db.models.fields.related.ForeignKey: payment_term>`

- `<django.db.models.fields.related.ForeignKey: purchase_account>`

Detail fields

- `<Panel main_1 in lino_amici.lib.contacts.models.PartnerDetail on lino_xl.lib.contacts.models.Partners>`

- `<Panel bottom_box_1 in lino_amici.lib.contacts.models.PartnerDetail on lino_xl.lib.contacts.models.Partners>`

Actions

- HTML (show_as_html) : Show this table in Bootstrap3 interface

- Table (landscape) (as_pdf) : Show this table as a pdf document.

- Import from text (import_text) : See `<lino_xl.lib.contacts.models.ImportText import_text ('Import from text')>`.

- Table (portrait) (as_pdf_p) : Show this table as a pdf document.

- Export as vCard (export_vcf) : Download all records as a .vcf file which you can import to another contacts application.

- Labels (print_labels) : Add this action to your table, which is expected to execute on a model which implements Addressable.

- Export to .xls (export_excel) : Export this table as an .xls document

- None (grid_post) : See `<lino.core.actions.CreateRow grid_post>`.

- None (grid_put) : See `<lino.core.actions.SaveGridCell grid_put>`.

- Create (submit_insert) : Create the record and open a detail window on it

- ⚇ (duplicate) : Duplicate the selected row.

- Detail (detail) : Open a detail window on this record.

- Delete (delete_selected) : Delete this record

- Merge (merge_row) : See `<lino.core.merge.MergeAction merge_row ('Merge')>`.

- Payment reminder (create_excerpt2) : Create an excerpt in order to print this data record.

- Debts (due) : See `<lino.core.actions.ShowSlaveTable due ('Debts')>`.

- Data problems (show_problems) : See `<lino.core.actions.ShowSlaveTable show_problems ('Data problems')>`.

- Upload files (show_uploads) : Show uploads in a grid table.

- Check data (check_data) : See `<lino.modlib.checkdata.models.UpdateProblemsByController check_data ('Check data')>`.

- None (del_company) : See `<lino.mixins.polymorphic.DeleteChild del_company>`.

- None (del_household) : See `<lino.mixins.polymorphic.DeleteChild del_household>`.

- None (del_partner) : See `<lino.mixins.polymorphic.DeleteChild del_partner>`.

- None (del_person) : See `<lino.mixins.polymorphic.DeleteChild del_person>`.

- Fix data problems (fix_problems) : See `<lino.modlib.checkdata.models.FixProblemsByController fix_problems ('Fix data problems')>`.

- None (grid) : See `<lino.core.actions.ShowTable grid>`.

- None (ins_company) : See `<lino.mixins.polymorphic.InsertChild ins_company>`.

- None (ins_household) : See `<lino.mixins.polymorphic.InsertChild ins_household>`.

- None (ins_partner) : See `<lino.mixins.polymorphic.InsertChild ins_partner>`.

- None (ins_person) : See `<lino.mixins.polymorphic.InsertChild ins_person>`.

- None (open_help) : See `<lino.core.actions.OpenHelpWindow open_help>`.

- None (validate) : See `<lino.core.actions.ValidateForm validate>`.

- Save (submit_detail) : Save changes in this form

Filter parameters

- `<lino.core.choicelists.ChoiceListField: observed_event>`

- `<django.db.models.fields.DateField: start_date>`

- `<django.db.models.fields.DateField: end_date>`

## Filter parameters